
import HocError from '@/Hoc/HocError'
import { Card, Col, Modal, Row, Table, Tag, Input, message } from 'antd'
import React, { useCallback, useEffect, useState } from 'react'
import { columnsMp } from './tableConfig'
import { useModel } from 'umi'
import { useAjax } from '@/Hook/useAjax'
import { putAdAccountApi } from '@/services/launchAdq/adAuthorize'
import style from './index.less'

/** 投放管理 */
const AdAuthorize: React.FC = () => {
    const { getAdAccount } = useModel('useLaunchAdq.useAdAuthorize')
    const [remarkData, set_remarkData] = useState<{
        visible: boolean,
        remark: string,
        data: any
    }>({
        visible: false,
        remark: '',
        data: null
    })
    const putRemark = useAjax((adAccountId: any, remark: any) => putAdAccountApi(adAccountId, remark))
    useEffect(() => {
        // 获取账号列表
        getAdAccount.run()
    }, [])
    const remark = useCallback(() => {
        if (remarkData.remark && remarkData.data) {
            putRemark.run(remarkData.data.id, remarkData.remark).then(res => {
                set_remarkData({...remarkData,visible:false,remark:'',data:null})
                getAdAccount.refresh()
            })
        } else {
            message.error('请输入备注！')
        }

    }, [getAdAccount, remarkData])
    const edit = useCallback((data) => {
        set_remarkData({ ...remarkData, visible: true, data,remark:data.remark})
    }, [remarkData])
    return <Card>
        <Table dataSource={getAdAccount?.data?.data} loading={getAdAccount?.loading} columns={columnsMp(edit)} size="small" bordered
            scroll={{ x: 2000 }}
            pagination={{
                position: ['bottomRight'],
                total: getAdAccount?.data?.data?.length,//总共多少条数据,服务器给,设置后分页自动计算页数
                showTotal: (total) => <Tag color="cyan">总共{total}数据</Tag>,
                showSizeChanger: true,
                showLessItems: true,
                defaultCurrent: 1,
                defaultPageSize: 20,//默认初始的每页条数
            }}
            rowKey={(row) => row.id}
        />
        {remarkData.visible && <Modal
            visible={remarkData.visible}
            title='编辑账户'
            onCancel={() => { set_remarkData({ ...remarkData, visible: false, data: null }) }}
            onOk={remark}
        >
            <Row gutter={[20, 20]}>
                <Col span={24} className={style.boxCol}><strong>广告主ID：</strong><span>{remarkData?.data.accountId}</span></Col>
                <Col span={24} className={style.boxCol}><strong>类型：</strong><span>{remarkData?.data.sourceType === 0 ? '微信' : 'QQ'}</span></Col>
                <Col span={24} className={style.boxCol}><strong>公众号信息：</strong><span>{remarkData?.data.wechatAccountName || '无'}</span></Col>
                <Col span={24} className={style.boxCol}><strong>企业名称：</strong><span>{remarkData?.data.corporationName || '无'}</span></Col>
                <Col span={24} className={style.boxCol}><strong>服务商ID列表：</strong><span>{remarkData?.data.agencyIdList ? remarkData.data.agencyIdList?.join() : '无'}</span></Col>
                <Col span={24} className={style.boxCol}><strong>行业ID：</strong><span>{remarkData?.data.systemIndustryId || '无'}</span></Col>
                <Col span={24} className={style.boxCol}><strong>授权状态：</strong><span>{remarkData?.data.authStatus || '无'}</span></Col>
                <Col span={24} className={style.boxCol}><strong>日限额(分)：</strong><span>{remarkData?.data.dailyBudget || '无'}</span></Col>
                <Col span={24} className={style.boxCol}><strong>授权时间：</strong><span>{remarkData?.data.createTime || '无'}</span></Col>
                <Col span={24} className={style.boxCol}><strong>备注：</strong><span><Input.TextArea rows={5} maxLength={200} value={remarkData.remark} onChange={(e) => {
                    let value = e.target.value
                    set_remarkData({ ...remarkData, remark: value })
                }} /></span></Col>
            </Row>
        </Modal>}
    </Card>
}

export default HocError(AdAuthorize)