import { useAjax } from "@/Hook/useAjax"
import { getTaskLogListApi, TaskLogListProps } from "@/services/launchAdq/taskList"
import { Button, Drawer, Select, Space } from "antd"
import React, { useEffect, useState } from "react"
import { useModel } from "umi"
import TableData from "../../components/TableData"
import tableConfig from './logTableConfig'

interface Props {
    taskId: number,  // 任务ID
    campaignName: string, // 计划名称
    visible?: boolean,
    onClose?: () => void
}
/**
 * 创建日志
 * @returns 
 */
const Log: React.FC<Props> = (props) => {

    /*****************************/
    const { taskId, campaignName, visible, onClose } = props
    const [queryForm, setQueryForm] = useState<TaskLogListProps>({ pageNum: 1, pageSize: 20, taskId })

    const { getAdAccount } = useModel('useLaunchAdq.useAdAuthorize')
    const getTaskLogList = useAjax((params) => getTaskLogListApi(params), { formatResult: true })
    /*****************************/

    useEffect(() => {
        getAdAccount.run()
    }, [])

    useEffect(() => {
        getList()
    }, [queryForm])

    const getList = () => {
        getTaskLogList.run(queryForm)
    }

    return <Drawer bodyStyle={{ padding: 0 }} title={campaignName + ' 日志'} width={1000} placement="right" onClose={() => { onClose && onClose() }} visible={visible}>
        <TableData
            columns={() => tableConfig()}
            ajax={getTaskLogList}
            dataSource={getTaskLogList?.data?.data?.records}
            loading={getTaskLogList?.loading}
            scroll={{ y: 600 }}
            total={getTaskLogList?.data?.data?.total}
            page={getTaskLogList?.data?.data?.current}
            pageSize={getTaskLogList?.data?.data?.size}
            leftChild={<Space>
                <Select
                    placeholder="媒体账户"
                    allowClear
                    style={{ width: 150 }}
                    showSearch
                    value={queryForm?.accountId}
                    filterOption={(input, option) => {
                        return (option?.children as unknown as string)?.toString()?.toLowerCase()?.includes(input.toLowerCase())
                    }}
                    onChange={(e) => { setQueryForm({ ...queryForm, accountId: e }) }}
                >
                    {getAdAccount?.data?.data?.map((item: any) => <Select.Option value={item.accountId} key={item.id}>{item.accountId}</Select.Option>)}
                </Select>
                <Select style={{ width: 150 }} allowClear value={queryForm?.createStatus} placeholder="创建状态" showSearch onChange={(e) => { setQueryForm({ ...queryForm, createStatus: e }) }}>
                    <Select.Option value={-1}>创建失败</Select.Option>
                    <Select.Option value={0}>创建中</Select.Option>
                    <Select.Option value={100}>创建成功</Select.Option>
                </Select>
            </Space>}
            onChange={(props: any) => {
                let { sortData, pagination } = props
                let { current, pageSize } = pagination
                setQueryForm({ ...queryForm, pageNum: current, pageSize })
            }}
        />
    </Drawer>
}


export default React.memo(Log)